.. meta::
    :description lang=en:
        Retrieve Twitter API data with a set of Python functions. Get Multiple
        results on a large scale and in a single pandas DataFrame.

.. automodule:: advertools.twitter
   :members:
   :undoc-members:
   :show-inheritance:
